# Generated by Django 3.1.4 on 2020-12-16 07:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("courses", "0025_auto_20201216_0917"),
    ]

    operations = [
        migrations.AddField(
            model_name="courserun",
            name="sync_mode",
            field=models.CharField(
                choices=[
                    ("manual", "Manual"),
                    ("sync_to_draft", "Synchronization to draft page"),
                    ("sync_to_public", "Synchronization to public page"),
                ],
                default="manual",
                max_length=20,
            ),
        ),
    ]
