{% load cms_tags i18n %}
{% spaceless %}
{% if target_page %}
  {% with category=target_page.category %}
    {% include "courses/cms/fragment_category_glimpse.html" %}
  {% endwith %}
{% endif %}
{% endspaceless %}
