# Generated by Django 2.2.8 on 2020-01-02 13:53

from django.db import migrations, models

import richie.apps.core.fields.multiselect


class Migration(migrations.Migration):

    dependencies = [("courses", "0010_auto_footer_to_static_placeholder")]

    operations = [
        migrations.RenameField(
            model_name="licence", old_name="content", new_name="content_deprecated"
        ),
        migrations.RenameField(
            model_name="licence", old_name="name", new_name="name_deprecated"
        ),
        migrations.AlterField(
            model_name="licence",
            name="content_deprecated",
            field=models.TextField(
                db_column="content", default="", verbose_name="content"
            ),
        ),
        migrations.AlterField(
            model_name="licence",
            name="name_deprecated",
            field=models.CharField(
                db_column="name", max_length=200, verbose_name="name"
            ),
        ),
    ]
