(self.webpackChunkrichie_education=self.webpackChunkrichie_education||[]).push([[63574],{63574:function(){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({data:{nu:["latn"],year:{0:"iste anno",1:"le anno proxime",future:{one:"in {0} annos",other:"in {0} annos"},past:{one:"{0} annos retro",other:"{0} annos retro"},"-1":"le anno passate"},"year-short":{0:"iste anno",1:"le anno proxime",future:{one:"in {0} annos",other:"in {0} an."},past:{one:"{0} annos retro",other:"{0} an. retro"},"-1":"le anno passate"},"year-narrow":{0:"iste anno",1:"le anno proxime",future:{one:"in {0} annos",other:"in {0} an."},past:{one:"{0} annos retro",other:"{0} an. retro"},"-1":"le anno passate"},quarter:{0:"iste trimestre",1:"le trimestre proxime",future:{one:"in {0} trimestres",other:"in {0} trimestres"},past:{one:"in {0} trimestres",other:"in {0} trimestres"},"-1":"le trimestre passate"},"quarter-short":{0:"iste trimestre",1:"le trimestre proxime",future:{one:"in {0} trimestres",other:"in {0} trim."},past:{one:"in {0} trimestres",other:"{0} trim. retro"},"-1":"le trimestre passate"},"quarter-narrow":{0:"iste trimestre",1:"le trimestre proxime",future:{one:"in {0} trimestres",other:"in {0} trim."},past:{one:"in {0} trimestres",other:"{0} trim. retro"},"-1":"le trimestre passate"},month:{0:"iste mense",1:"le mense proxime",future:{one:"in {0} menses",other:"in {0} menses"},past:{one:"{0} menses retro",other:"{0} menses retro"},"-1":"le mense passate"},"month-short":{0:"iste mense",1:"le mense proxime",future:{one:"in {0} menses",other:"in {0} mns."},past:{one:"{0} menses retro",other:"{0} mns. retro"},"-1":"le mense passate"},"month-narrow":{0:"iste mense",1:"le mense proxime",future:{one:"in {0} menses",other:"in {0} mns."},past:{one:"{0} menses retro",other:"{0} mns. retro"},"-1":"le mense passate"},week:{0:"iste septimana",1:"le septimana proxime",future:{one:"in {0} septimanas",other:"in {0} septimanas"},past:{one:"{0} septimanas retro",other:"{0} septimanas retro"},"-1":"le septimana passate"},"week-short":{0:"iste septimana",1:"le septimana proxime",future:{one:"in {0} septimanas",other:"in {0} sept."},past:{one:"{0} septimanas retro",other:"{0} sept. retro"},"-1":"le septimana passate"},"week-narrow":{0:"iste septimana",1:"le septimana proxime",future:{one:"in {0} septimanas",other:"in {0} sept."},past:{one:"{0} septimanas retro",other:"{0} sept. retro"},"-1":"le septimana passate"},day:{0:"hodie",1:"deman",future:{one:"in {0} dies",other:"in {0} dies"},past:{one:"{0} dies retro",other:"{0} dies retro"},"-1":"heri"},"day-short":{0:"hodie",1:"deman",future:{one:"in {0} dies",other:"in {0} dies"},past:{one:"{0} dies retro",other:"{0} dies retro"},"-1":"heri"},"day-narrow":{0:"hodie",1:"deman",future:{one:"in {0} dies",other:"in {0} dies"},past:{one:"{0} dies retro",other:"{0} dies retro"},"-1":"heri"},hour:{0:"iste hora",future:{one:"in {0} horas",other:"in {0} horas"},past:{one:"{0} horas retro",other:"{0} horas retro"}},"hour-short":{0:"iste hora",future:{one:"in {0} horas",other:"in {0} hr."},past:{one:"{0} horas retro",other:"{0} hr. retro"}},"hour-narrow":{0:"iste hora",future:{one:"in {0} horas",other:"in {0} hr."},past:{one:"{0} horas retro",other:"{0} hr. retro"}},minute:{0:"iste minuta",future:{one:"in {0} minutas",other:"in {0} minutas"},past:{one:"{0} minutas retro",other:"{0} minutas retro"}},"minute-short":{0:"iste minuta",future:{one:"in {0} minutas",other:"in {0} min."},past:{one:"{0} minutas retro",other:"{0} min. retro"}},"minute-narrow":{0:"iste minuta",future:{one:"in {0} minutas",other:"in {0} min."},past:{one:"{0} minutas retro",other:"{0} min. retro"}},second:{0:"ora",future:{one:"in {0} secundas",other:"in {0} secundas"},past:{one:"{0} secundas retro",other:"{0} secundas retro"}},"second-short":{0:"ora",future:{one:"in {0} secundas",other:"in {0} sec."},past:{one:"{0} secundas retro",other:"{0} sec. retro"}},"second-narrow":{0:"ora",future:{one:"in {0} secundas",other:"in {0} sec."},past:{one:"{0} secundas retro",other:"{0} sec. retro"}}},locale:"ia"})}}]);
//# sourceMappingURL=63574.0de783458d0ed5127629.index.js.map