# Generated by Django 2.1.7 on 2019-02-23 01:18

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models

import filer.fields.image


class Migration(migrations.Migration):

    dependencies = [("large_banner", "0002_add_template_and_content_fields")]

    operations = [
        migrations.AlterField(
            model_name="largebanner",
            name="logo",
            field=filer.fields.image.FilerImageField(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="logo",
                to=settings.FILER_IMAGE_MODEL,
                verbose_name="logo",
            ),
        ),
        migrations.AlterField(
            model_name="largebanner",
            name="logo_alt_text",
            field=models.CharField(blank=True, max_length=255),
        ),
    ]
