(self.webpackChunkrichie_education=self.webpackChunkrichie_education||[]).push([[18856],{69533:function(e,t){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var a=new WeakMap;t.default=function(e){var t=a.get(e);return t||(t=Object.create(null),a.set(e,t)),t}},18856:function(e,t,a){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var o=a(33940),l=a(14034),n=o.__importDefault(a(69533)),r=function(){function e(t,a){if(!(this&&this instanceof e?this.constructor:void 0))throw new TypeError("Intl.RelativeTimeFormat must be called with 'new'");return l.InitializeRelativeTimeFormat(this,t,a,{getInternalSlots:n.default,availableLocales:e.availableLocales,relevantExtensionKeys:e.relevantExtensionKeys,localeData:e.localeData,getDefaultLocale:e.getDefaultLocale})}return e.prototype.format=function(e,t){if("object"!=typeof this)throw new TypeError("format was called on a non-object");if(!n.default(this).initializedRelativeTimeFormat)throw new TypeError("format was called on a invalid context");return l.PartitionRelativeTimePattern(this,Number(e),l.ToString(t),{getInternalSlots:n.default}).map((function(e){return e.value})).join("")},e.prototype.formatToParts=function(e,t){if("object"!=typeof this)throw new TypeError("formatToParts was called on a non-object");if(!n.default(this).initializedRelativeTimeFormat)throw new TypeError("formatToParts was called on a invalid context");return l.PartitionRelativeTimePattern(this,Number(e),l.ToString(t),{getInternalSlots:n.default})},e.prototype.resolvedOptions=function(){if("object"!=typeof this)throw new TypeError("resolvedOptions was called on a non-object");var e=n.default(this);if(!e.initializedRelativeTimeFormat)throw new TypeError("resolvedOptions was called on a invalid context");return{locale:e.locale,style:e.style,numeric:e.numeric,numberingSystem:e.numberingSystem}},e.supportedLocalesOf=function(t,a){return l.SupportedLocales(e.availableLocales,l.CanonicalizeLocaleList(t),a)},e.__addLocaleData=function(){for(var t=[],a=0;a<arguments.length;a++)t[a]=arguments[a];for(var o=0,l=t;o<l.length;o++){var n=l[o],r=n.data,i=n.locale,c=new Intl.Locale(i).minimize().toString();e.localeData[i]=e.localeData[c]=r,e.availableLocales.add(c),e.availableLocales.add(i),e.__defaultLocale||(e.__defaultLocale=c)}},e.getDefaultLocale=function(){return e.__defaultLocale},e.localeData={},e.availableLocales=new Set,e.__defaultLocale="",e.relevantExtensionKeys=["nu"],e.polyfilled=!0,e}();t.default=r;try{"undefined"!=typeof Symbol&&Object.defineProperty(r.prototype,Symbol.toStringTag,{value:"Intl.RelativeTimeFormat",writable:!1,enumerable:!1,configurable:!0}),Object.defineProperty(r.prototype.constructor,"length",{value:0,writable:!1,enumerable:!1,configurable:!0}),Object.defineProperty(r.supportedLocalesOf,"length",{value:1,writable:!1,enumerable:!1,configurable:!0})}catch(e){}}}]);
//# sourceMappingURL=18856.0de783458d0ed5127629.index.js.map