(self.webpackChunkrichie_education=self.webpackChunkrichie_education||[]).push([[82487],{82487:function(){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({data:{nu:["latn"],year:{0:"shu yil",1:"keyingi yil",future:{one:"{0} yildan keyin",other:"{0} yildan keyin"},past:{one:"{0} yil oldin",other:"{0} yil oldin"},"-1":"o‘tgan yil"},"year-short":{0:"bu yil",1:"keyingi yil",future:{one:"{0} yildan keyin",other:"{0} yildan keyin"},past:{one:"{0} yil oldin",other:"{0} yil oldin"},"-1":"o‘ʻtgan yil"},"year-narrow":{0:"bu yil",1:"keyingi yil",future:{one:"{0} yildan keyin",other:"{0} yildan keyin"},past:{one:"{0} yil oldin",other:"{0} yil oldin"},"-1":"o‘tgan yil"},quarter:{0:"shu chorak",1:"keyingi chorak",future:{one:"{0} chorakdan keyin",other:"{0} chorakdan keyin"},past:{one:"{0} chorak oldin",other:"{0} chorak oldin"},"-1":"o‘tgan chorak"},"quarter-short":{0:"shu chorak",1:"keyingi chorak",future:{one:"{0} chorakdan keyin",other:"{0} chorakdan keyin"},past:{one:"{0} chorak oldin",other:"{0} chorak oldin"},"-1":"o‘tgan chorak"},"quarter-narrow":{0:"shu chorak",1:"keyingi chorak",future:{one:"{0} chorakdan keyin",other:"{0} chorakdan keyin"},past:{one:"{0} chorak oldin",other:"{0} chorak oldin"},"-1":"o‘tgan chorak"},month:{0:"shu oy",1:"keyingi oy",future:{one:"{0} oydan keyin",other:"{0} oydan keyin"},past:{one:"{0} oy oldin",other:"{0} oy oldin"},"-1":"o‘tgan oy"},"month-short":{0:"bu oy",1:"keyingi oy",future:{one:"{0} oydan keyin",other:"{0} oydan keyin"},past:{one:"{0} oy oldin",other:"{0} oy oldin"},"-1":"o‘tgan oy"},"month-narrow":{0:"bu oy",1:"keyingi oy",future:{one:"{0} oydan keyin",other:"{0} oydan keyin"},past:{one:"{0} oy oldin",other:"{0} oy oldin"},"-1":"o‘tgan oy"},week:{0:"shu hafta",1:"keyingi hafta",future:{one:"{0} haftadan keyin",other:"{0} haftadan keyin"},past:{one:"{0} hafta oldin",other:"{0} hafta oldin"},"-1":"o‘tgan hafta"},"week-short":{0:"bu hafta",1:"keyingi hafta",future:{one:"{0} haftadan keyin",other:"{0} haftadan keyin"},past:{one:"{0} hafta oldin",other:"{0} hafta oldin"},"-1":"o‘tgan hafta"},"week-narrow":{0:"bu hafta",1:"keyingi hafta",future:{one:"{0} haftadan keyin",other:"{0} haftadan keyin"},past:{one:"{0} hafta oldin",other:"{0} hafta oldin"},"-1":"o‘tgan hafta"},day:{0:"bugun",1:"ertaga",future:{one:"{0} kundan keyin",other:"{0} kundan keyin"},past:{one:"{0} kun oldin",other:"{0} kun oldin"},"-1":"kecha"},"day-short":{0:"bugun",1:"ertaga",future:{one:"{0} kundan keyin",other:"{0} kundan keyin"},past:{one:"{0} kun oldin",other:"{0} kun oldin"},"-1":"kecha"},"day-narrow":{0:"bugun",1:"ertaga",future:{one:"{0} kundan keyin",other:"{0} kundan keyin"},past:{one:"{0} kun oldin",other:"{0} kun oldin"},"-1":"kecha"},hour:{0:"shu soatda",future:{one:"{0} soatdan keyin",other:"{0} soatdan keyin"},past:{one:"{0} soat oldin",other:"{0} soat oldin"}},"hour-short":{0:"shu soatda",future:{one:"{0} soatdan keyin",other:"{0} soatdan keyin"},past:{one:"{0} soat oldin",other:"{0} soat oldin"}},"hour-narrow":{0:"shu soatda",future:{one:"{0} soatdan keyin",other:"{0} soatdan keyin"},past:{one:"{0} soat oldin",other:"{0} soat oldin"}},minute:{0:"shu daqiqada",future:{one:"{0} daqiqadan keyin",other:"{0} daqiqadan keyin"},past:{one:"{0} daqiqa oldin",other:"{0} daqiqa oldin"}},"minute-short":{0:"shu daqiqada",future:{one:"{0} daqiqadan keyin",other:"{0} daqiqadan keyin"},past:{one:"{0} daqiqa oldin",other:"{0} daqiqa oldin"}},"minute-narrow":{0:"shu daqiqada",future:{one:"{0} daqiqadan keyin",other:"{0} daqiqadan keyin"},past:{one:"{0} daqiqa oldin",other:"{0} daqiqa oldin"}},second:{0:"hozir",future:{one:"{0} soniyadan keyin",other:"{0} soniyadan keyin"},past:{one:"{0} soniya oldin",other:"{0} soniya oldin"}},"second-short":{0:"hozir",future:{one:"{0} soniyadan keyin",other:"{0} soniyadan keyin"},past:{one:"{0} soniya oldin",other:"{0} soniya oldin"}},"second-narrow":{0:"hozir",future:{one:"{0} soniyadan keyin",other:"{0} soniyadan keyin"},past:{one:"{0} soniya oldin",other:"{0} soniya oldin"}}},locale:"uz-Latn"})}}]);
//# sourceMappingURL=82487.0de783458d0ed5127629.index.js.map