(self.webpackChunkrichie_education=self.webpackChunkrichie_education||[]).push([[52320],{52320:function(){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({data:{nu:["latn"],year:{0:"taun iki",1:"taun ngarep",future:{other:"ing {0} taun"},past:{other:"{0} taun kepungkur"},"-1":"taun wingi"},"year-short":{0:"taun iki",1:"taun ngarep",future:{other:"ing {0} taun"},past:{other:"{0} taun kepungkur"},"-1":"taun wingi"},"year-narrow":{0:"taun iki",1:"taun ngarep",future:{other:"ing {0} taun"},past:{other:"{0} taun kepungkur"},"-1":"taun wingi"},quarter:{0:"triwulan iki",1:"triwulan ngarep",future:{other:"ing {0} triwulan"},past:{other:"{0} triwulan kepungkur"},"-1":"triwulan wingi"},"quarter-short":{0:"triwulan iki",1:"triwulan ngarep",future:{other:"ing {0} triwulan"},past:{other:"{0} triwulan kepungkur"},"-1":"triwulan wingi"},"quarter-narrow":{0:"triwulan iki",1:"triwulan ngarep",future:{other:"ing {0} triwulan"},past:{other:"{0} triwulan kepungkur"},"-1":"triwulan wingi"},month:{0:"sasi iki",1:"sasi ngarep",future:{other:"ing {0} sasi"},past:{other:"{0} sasi kepungkur"},"-1":"sasi wingi"},"month-short":{0:"sasi iki",1:"sasi ngarep",future:{other:"ing {0} sasi"},past:{other:"{0} sasi kepungkur"},"-1":"sasi wingi"},"month-narrow":{0:"sasi iki",1:"sasi ngarep",future:{other:"ing {0} sasi"},past:{other:"{0} sasi kepungkur"},"-1":"sasi wingi"},week:{0:"pekan iki",1:"pekan ngarep",future:{other:"ing {0} pekan"},past:{other:"{0} pekan kepungkur"},"-1":"pekan wingi"},"week-short":{0:"pekan iki",1:"pekan ngarep",future:{other:"ing {0} pekan"},past:{other:"{0} pekan kepungkur"},"-1":"pekan wingi"},"week-narrow":{0:"pekan iki",1:"pekan ngarep",future:{other:"ing {0} pekan"},past:{other:"{0} pekan kepungkur"},"-1":"pekan wingi"},day:{0:"dino iki",1:"sesuk",future:{other:"ing {0} dina"},past:{other:"{0} dina kepungkur"},"-1":"wingi"},"day-short":{0:"dino iki",1:"sesuk",future:{other:"ing {0} dina"},past:{other:"{0} dina kepungkur"},"-1":"wingi"},"day-narrow":{0:"dino iki",1:"sesuk",future:{other:"ing {0} dina"},past:{other:"{0} dino kepungkur"},"-1":"wingi"},hour:{0:"jam iki",future:{other:"ing {0} jam"},past:{other:"{0} jam kepungkur"}},"hour-short":{0:"jam iki",future:{other:"ing {0} jam"},past:{other:"{0} jam kepungkur"}},"hour-narrow":{0:"jam iki",future:{other:"ing {0} jam"},past:{other:"{0} jam kepungkur"}},minute:{0:"menit iki",future:{other:"ing {0} menit"},past:{other:"{0} menit kepungkur"}},"minute-short":{0:"menit iki",future:{other:"ing {0} menit"},past:{other:"{0} menit kepungkur"}},"minute-narrow":{0:"menit iki",future:{other:"ing {0} menit"},past:{other:"{0} menit kepungkur"}},second:{0:"saiki",future:{other:"ing {0} detik"},past:{other:"{0} detik kepungkur"}},"second-short":{0:"saiki",future:{other:"ing {0} detik"},past:{other:"{0} detik kepungkur"}},"second-narrow":{0:"saiki",future:{other:"ing {0} detik"},past:{other:"{0} detik kepungkur"}}},locale:"jv"})}}]);
//# sourceMappingURL=52320.0de783458d0ed5127629.index.js.map