# Generated by Django 2.2.15 on 2020-08-27 08:11

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("courses", "0016_auto_20200417_1237"),
    ]

    operations = [
        migrations.AlterField(
            model_name="courserun",
            name="resource_link",
            field=models.CharField(
                blank=True, max_length=200, null=True, verbose_name="Resource link"
            ),
        ),
    ]
