(self.webpackChunkrichie_education=self.webpackChunkrichie_education||[]).push([[27596],{27596:function(){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({data:{nu:["latn"],year:{0:"اس سال",1:"اگلے سال",future:{one:"{0} سال میں",other:"{0} سال میں"},past:{one:"{0} سال پہلے",other:"{0} سال پہلے"},"-1":"گزشتہ سال"},"year-short":{0:"اس سال",1:"اگلے سال",future:{one:"{0} سال میں",other:"{0} سال میں"},past:{one:"{0} سال پہلے",other:"{0} سال پہلے"},"-1":"گزشتہ سال"},"year-narrow":{0:"اس سال",1:"اگلے سال",future:{one:"{0} سال میں",other:"{0} سال میں"},past:{one:"{0} سال پہلے",other:"{0} سال پہلے"},"-1":"گزشتہ سال"},quarter:{0:"اس سہ ماہی",1:"اگلے سہ ماہی",future:{one:"{0} سہ ماہی میں",other:"{0} سہ ماہی میں"},past:{one:"{0} سہ ماہی پہلے",other:"{0} سہ ماہی پہلے"},"-1":"گزشتہ سہ ماہی"},"quarter-short":{0:"اس سہ ماہی",1:"اگلے سہ ماہی",future:{one:"{0} سہ ماہی میں",other:"{0} سہ ماہی میں"},past:{one:"{0} سہ ماہی قبل",other:"{0} سہ ماہی قبل"},"-1":"گزشتہ سہ ماہی"},"quarter-narrow":{0:"اس سہ ماہی",1:"اگلے سہ ماہی",future:{one:"{0} سہ ماہی میں",other:"{0} سہ ماہی میں"},past:{one:"{0} سہ ماہی پہلے",other:"{0} سہ ماہی پہلے"},"-1":"گزشتہ سہ ماہی"},month:{0:"اس ماہ",1:"اگلا مہینہ",future:{one:"{0} مہینہ میں",other:"{0} مہینے میں"},past:{one:"{0} مہینہ پہلے",other:"{0} مہینے پہلے"},"-1":"گزشتہ ماہ"},"month-short":{0:"اس مہینہ",1:"اگلے مہینہ",future:{one:"{0} ماہ میں",other:"{0} ماہ میں"},past:{one:"{0} ماہ قبل",other:"{0} ماہ قبل"},"-1":"پچھلے مہینہ"},"month-narrow":{0:"اس ماہ",1:"اگلے ماہ",future:{one:"{0} ماہ میں",other:"{0} ماہ میں"},past:{one:"{0} ماہ پہلے",other:"{0} ماہ پہلے"},"-1":"گزشتہ ماہ"},week:{0:"اس ہفتہ",1:"اگلے ہفتے",future:{one:"{0} ہفتہ میں",other:"{0} ہفتے میں"},past:{one:"{0} ہفتہ پہلے",other:"{0} ہفتے پہلے"},"-1":"گزشتہ ہفتے"},"week-short":{0:"اس ہفتہ",1:"اگلے ہفتہ",future:{one:"{0} ہفتے میں",other:"{0} ہفتے میں"},past:{one:"{0} ہفتے پہلے",other:"{0} ہفتے پہلے"},"-1":"پچھلے ہفتہ"},"week-narrow":{0:"اس ہفتہ",1:"اگلے ہفتہ",future:{one:"{0} ہفتہ میں",other:"{0} ہفتے میں"},past:{one:"{0} ہفتہ پہلے",other:"{0} ہفتے پہلے"},"-1":"پچھلے ہفتہ"},day:{0:"آج",1:"آئندہ کل",2:"آنے والا پرسوں",future:{one:"{0} دن میں",other:"{0} دنوں میں"},past:{one:"{0} دن پہلے",other:"{0} دنوں پہلے"},"-2":"گزشتہ پرسوں","-1":"گزشتہ کل"},"day-short":{0:"آج",1:"آئندہ کل",2:"آنے والا پرسوں",future:{one:"{0} دن میں",other:"{0} دنوں میں"},past:{one:"{0} دن پہلے",other:"{0} دن پہلے"},"-2":"گزشتہ پرسوں","-1":"گزشتہ کل"},"day-narrow":{0:"آج",1:"آئندہ کل",2:"آنے والا پرسوں",future:{one:"{0} دن میں",other:"{0} دنوں میں"},past:{one:"{0} دن پہلے",other:"{0} دن پہلے"},"-2":"گزشتہ پرسوں","-1":"گزشتہ کل"},hour:{0:"اس گھنٹے",future:{one:"{0} گھنٹے میں",other:"{0} گھنٹے میں"},past:{one:"{0} گھنٹہ پہلے",other:"{0} گھنٹے پہلے"}},"hour-short":{0:"اس گھنٹے",future:{one:"{0} گھنٹے میں",other:"{0} گھنٹے میں"},past:{one:"{0} گھنٹے پہلے",other:"{0} گھنٹے پہلے"}},"hour-narrow":{0:"اس گھنٹے",future:{one:"{0} گھنٹے میں",other:"{0} گھنٹوں میں"},past:{one:"{0} گھنٹہ پہلے",other:"{0} گھنٹے پہلے"}},minute:{0:"اس منٹ",future:{one:"{0} منٹ میں",other:"{0} منٹ میں"},past:{one:"{0} منٹ پہلے",other:"{0} منٹ پہلے"}},"minute-short":{0:"اس منٹ",future:{one:"{0} منٹ میں",other:"{0} منٹ میں"},past:{one:"{0} منٹ پہلے",other:"{0} منٹ پہلے"}},"minute-narrow":{0:"اس منٹ",future:{one:"{0} منٹ میں",other:"{0} منٹ میں"},past:{one:"{0} منٹ پہلے",other:"{0} منٹ پہلے"}},second:{0:"اب",future:{one:"{0} سیکنڈ میں",other:"{0} سیکنڈ میں"},past:{one:"{0} سیکنڈ پہلے",other:"{0} سیکنڈ پہلے"}},"second-short":{0:"اب",future:{one:"{0} سیکنڈ میں",other:"{0} سیکنڈ میں"},past:{one:"{0} سیکنڈ پہلے",other:"{0} سیکنڈ پہلے"}},"second-narrow":{0:"اب",future:{one:"{0} سیکنڈ میں",other:"{0} سیکنڈ میں"},past:{one:"{0} سیکنڈ پہلے",other:"{0} سیکنڈ پہلے"}}},locale:"ur"})}}]);
//# sourceMappingURL=27596.0de783458d0ed5127629.index.js.map