{% load cms_tags i18n %}
{% spaceless %}
{% if target_page %}
  {% if person_variant == "tag" %}
    <a class="person-plugin-tag" href="{{ target_page.get_absolute_url }}">
      {{ target_page.get_title }}
    </a>
  {% else %}
    {% include "courses/cms/fragment_person_glimpse.html" with person=target_page.person %}
  {% endif %}
{% endif %}
{% endspaceless %}
