(self.webpackChunkrichie_education=self.webpackChunkrichie_education||[]).push([[98285],{98285:function(){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({data:{nu:["latn"],year:{0:"este año",1:"el próximo año",future:{one:"dentro de {0} año",other:"dentro de {0} años"},past:{one:"hace {0} año",other:"hace {0} años"},"-1":"el año pasado"},"year-short":{0:"este año",1:"el próximo año",future:{one:"dentro de {0} a",other:"dentro de {0} a"},past:{one:"hace {0} a",other:"hace {0} a"},"-1":"el año pasado"},"year-narrow":{0:"este año",1:"el próximo año",future:{one:"dentro de {0} a",other:"dentro de {0} a"},past:{one:"hace {0} a",other:"hace {0} a"},"-1":"el año pasado"},quarter:{0:"este trimestre",1:"el próximo trimestre",future:{one:"dentro de {0} trimestre",other:"dentro de {0} trimestres"},past:{one:"hace {0} trimestre",other:"hace {0} trimestres"},"-1":"el trimestre pasado"},"quarter-short":{0:"este trimestre",1:"el próximo trimestre",future:{one:"dentro de {0} trim.",other:"dentro de {0} trim."},past:{one:"hace {0} trim.",other:"hace {0} trim."},"-1":"el trimestre pasado"},"quarter-narrow":{0:"este trimestre",1:"el próximo trimestre",future:{one:"dentro de {0} trim.",other:"dentro de {0} trim."},past:{one:"hace {0} trim.",other:"hace {0} trim."},"-1":"el trimestre pasado"},month:{0:"este mes",1:"el próximo mes",future:{one:"dentro de {0} mes",other:"dentro de {0} meses"},past:{one:"hace {0} mes",other:"hace {0} meses"},"-1":"el mes pasado"},"month-short":{0:"este mes",1:"el próximo mes",future:{one:"dentro de {0} m",other:"dentro de {0} m"},past:{one:"hace {0} m",other:"hace {0} m"},"-1":"el mes pasado"},"month-narrow":{0:"este mes",1:"el próximo mes",future:{one:"dentro de {0} m",other:"dentro de {0} m"},past:{one:"hace {0} m",other:"hace {0} m"},"-1":"el mes pasado"},week:{0:"esta semana",1:"la próxima semana",future:{one:"dentro de {0} semana",other:"dentro de {0} semanas"},past:{one:"hace {0} semana",other:"hace {0} semanas"},"-1":"la semana pasada"},"week-short":{0:"esta sem.",1:"próx. sem.",future:{one:"dentro de {0} sem.",other:"dentro de {0} sem."},past:{one:"hace {0} sem.",other:"hace {0} sem."},"-1":"sem. pas."},"week-narrow":{0:"esta sem.",1:"próx. sem.",future:{one:"dentro de {0} sem.",other:"dentro de {0} sem."},past:{one:"hace {0} sem.",other:"hace {0} sem."},"-1":"sem. pas."},day:{0:"hoy",1:"mañana",2:"pasado mañana",future:{one:"dentro de {0} día",other:"dentro de {0} días"},past:{one:"hace {0} día",other:"hace {0} días"},"-2":"anteayer","-1":"ayer"},"day-short":{0:"hoy",1:"mañana",2:"pasado mañana",future:{one:"dentro de {0} día",other:"dentro de {0} días"},past:{one:"hace {0} día",other:"hace {0} días"},"-2":"anteayer","-1":"ayer"},"day-narrow":{0:"hoy",1:"mañana",2:"pasado mañana",future:{one:"dentro de {0} día",other:"dentro de {0} días"},past:{one:"hace {0} día",other:"hace {0} días"},"-2":"anteayer","-1":"ayer"},hour:{0:"esta hora",future:{one:"dentro de {0} hora",other:"dentro de {0} horas"},past:{one:"hace {0} hora",other:"hace {0} horas"}},"hour-short":{0:"esta hora",future:{one:"dentro de {0} h",other:"dentro de {0} h"},past:{one:"hace {0} h",other:"hace {0} h"}},"hour-narrow":{0:"esta hora",future:{one:"dentro de {0} h",other:"dentro de {0} h"},past:{one:"hace {0} h",other:"hace {0} h"}},minute:{0:"este minuto",future:{one:"dentro de {0} minuto",other:"dentro de {0} minutos"},past:{one:"hace {0} minuto",other:"hace {0} minutos"}},"minute-short":{0:"este minuto",future:{one:"dentro de {0} min",other:"dentro de {0} min"},past:{one:"hace {0} min",other:"hace {0} min"}},"minute-narrow":{0:"este minuto",future:{one:"dentro de {0} min",other:"dentro de {0} min"},past:{one:"hace {0} min",other:"hace {0} min"}},second:{0:"ahora",future:{one:"dentro de {0} segundo",other:"dentro de {0} segundos"},past:{one:"hace {0} segundo",other:"hace {0} segundos"}},"second-short":{0:"ahora",future:{one:"dentro de {0} s",other:"dentro de {0} s"},past:{one:"hace {0} s",other:"hace {0} s"}},"second-narrow":{0:"ahora",future:{one:"dentro de {0} s",other:"dentro de {0} s"},past:{one:"hace {0} s",other:"hace {0} s"}}},locale:"es-EC"})}}]);
//# sourceMappingURL=98285.0de783458d0ed5127629.index.js.map