(self.webpackChunkrichie_education=self.webpackChunkrichie_education||[]).push([[69443],{69443:function(){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({data:{nu:["latn"],year:{0:"diß Johr",1:"näx Johr",future:{zero:"en keinem Johr",one:"en {0} Johr",other:"en {0} Johre"},past:{zero:"vör keijnem Johr",one:"vör {0} Johr",other:"vör {0} Johre"},"-1":"läz Johr"},"year-short":{0:"diß Johr",1:"näx Johr",future:{zero:"en keinem Johr",one:"en {0} Johr",other:"en {0} Johre"},past:{zero:"vör keijnem Johr",one:"vör {0} Johr",other:"vör {0} Johre"},"-1":"läz Johr"},"year-narrow":{0:"diß Johr",1:"näx Johr",future:{zero:"en keinem Johr",one:"en {0} Johr",other:"en {0} Johre"},past:{zero:"vör keijnem Johr",one:"vör {0} Johr",other:"vör {0} Johre"},"-1":"läz Johr"},quarter:{0:"this quarter",1:"next quarter",future:{other:"+{0} Q"},past:{other:"-{0} Q"},"-1":"last quarter"},"quarter-short":{0:"this quarter",1:"next quarter",future:{other:"+{0} Q"},past:{other:"-{0} Q"},"-1":"last quarter"},"quarter-narrow":{0:"this quarter",1:"next quarter",future:{other:"+{0} Q"},past:{other:"-{0} Q"},"-1":"last quarter"},month:{0:"diese Mohnd",1:"nächste Mohnd",future:{other:"+{0} m"},past:{other:"-{0} m"},"-1":"lätzde Mohnd"},"month-short":{0:"diese Mohnd",1:"nächste Mohnd",future:{other:"+{0} m"},past:{other:"-{0} m"},"-1":"lätzde Mohnd"},"month-narrow":{0:"diese Mohnd",1:"nächste Mohnd",future:{other:"+{0} m"},past:{other:"-{0} m"},"-1":"lätzde Mohnd"},week:{0:"di Woch",1:"nächste Woche",future:{other:"+{0} w"},past:{other:"-{0} w"},"-1":"läz Woch"},"week-short":{0:"di Woch",1:"nächste Woche",future:{other:"+{0} w"},past:{other:"-{0} w"},"-1":"läz Woch"},"week-narrow":{0:"di Woch",1:"nächste Woche",future:{other:"+{0} w"},past:{other:"-{0} w"},"-1":"läz Woch"},day:{0:"hück",1:"morje",2:"övvermorje",future:{other:"+{0} d"},past:{other:"-{0} d"},"-2":"vörjestere","-1":"jestere"},"day-short":{0:"hück",1:"morje",2:"övvermorje",future:{other:"+{0} d"},past:{other:"-{0} d"},"-2":"vörjestere","-1":"jestere"},"day-narrow":{0:"hück",1:"morje",2:"övvermorje",future:{other:"+{0} d"},past:{other:"-{0} d"},"-2":"vörjestere","-1":"jestere"},hour:{0:"this hour",future:{other:"+{0} h"},past:{other:"-{0} h"}},"hour-short":{0:"this hour",future:{other:"+{0} h"},past:{other:"-{0} h"}},"hour-narrow":{0:"this hour",future:{other:"+{0} h"},past:{other:"-{0} h"}},minute:{0:"this minute",future:{other:"+{0} min"},past:{other:"-{0} min"}},"minute-short":{0:"this minute",future:{other:"+{0} min"},past:{other:"-{0} min"}},"minute-narrow":{0:"this minute",future:{other:"+{0} min"},past:{other:"-{0} min"}},second:{0:"now",future:{other:"+{0} s"},past:{other:"-{0} s"}},"second-short":{0:"now",future:{other:"+{0} s"},past:{other:"-{0} s"}},"second-narrow":{0:"now",future:{other:"+{0} s"},past:{other:"-{0} s"}}},locale:"ksh"})}}]);
//# sourceMappingURL=69443.0de783458d0ed5127629.index.js.map