(self.webpackChunkrichie_education=self.webpackChunkrichie_education||[]).push([[91778],{91778:function(){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({data:{nu:["latn"],year:{0:"îsal",1:"sala piştî",future:{one:"di salekê de",other:"di {0} salan de"},past:{one:"berî {0} salê",other:"berî {0} salan"},"-1":"par"},"year-short":{0:"îsal",1:"sala bê",future:{one:"piştî salekê",other:"piştî {0} salan"},past:{one:"berî salekê",other:"berî {0} salan"},"-1":"par"},"year-narrow":{0:"îsal",1:"sala bê",future:{one:"piştî salekê",other:"piştî {0} salan"},past:{one:"berî salekê",other:"berî {0} salan"},"-1":"par"},quarter:{0:"this quarter",1:"next quarter",future:{other:"+{0} Q"},past:{other:"-{0} Q"},"-1":"last quarter"},"quarter-short":{0:"this quarter",1:"next quarter",future:{other:"+{0} Q"},past:{other:"-{0} Q"},"-1":"last quarter"},"quarter-narrow":{0:"this quarter",1:"next quarter",future:{other:"+{0} Q"},past:{other:"-{0} Q"},"-1":"last quarter"},month:{0:"vê mehê",1:"meha were",future:{other:"+{0} m"},past:{other:"-{0} m"},"-1":"meha borî"},"month-short":{0:"vê mehê",1:"meha bê",future:{other:"+{0} m"},past:{other:"-{0} m"},"-1":"meha br."},"month-narrow":{0:"vê mehê",1:"meha bê",future:{other:"+{0} m"},past:{other:"-{0} m"},"-1":"meha br."},week:{0:"vê hefteyê",1:"hefteya were",future:{other:"+{0} w"},past:{other:"-{0} w"},"-1":"hefteya borî"},"week-short":{0:"vê hft.",1:"hft. bê",future:{other:"+{0} w"},past:{other:"-{0} w"},"-1":"hft. borî"},"week-narrow":{0:"vê hft.",1:"hft. bê",future:{other:"+{0} w"},past:{other:"-{0} w"},"-1":"hft. borî"},day:{0:"îro",1:"sibe",future:{other:"+{0} d"},past:{other:"-{0} d"},"-1":"duh"},"day-short":{0:"îro",1:"sibe",future:{other:"+{0} d"},past:{other:"-{0} d"},"-1":"duh"},"day-narrow":{0:"îro",1:"sibe",future:{other:"+{0} d"},past:{other:"-{0} d"},"-1":"duh"},hour:{0:"this hour",future:{other:"+{0} h"},past:{other:"-{0} h"}},"hour-short":{0:"this hour",future:{other:"+{0} h"},past:{other:"-{0} h"}},"hour-narrow":{0:"this hour",future:{other:"+{0} h"},past:{other:"-{0} h"}},minute:{0:"this minute",future:{other:"+{0} min"},past:{other:"-{0} min"}},"minute-short":{0:"this minute",future:{other:"+{0} min"},past:{other:"-{0} min"}},"minute-narrow":{0:"this minute",future:{other:"+{0} min"},past:{other:"-{0} min"}},second:{0:"now",future:{other:"+{0} s"},past:{other:"-{0} s"}},"second-short":{0:"now",future:{other:"+{0} s"},past:{other:"-{0} s"}},"second-narrow":{0:"now",future:{other:"+{0} s"},past:{other:"-{0} s"}}},locale:"ku"})}}]);
//# sourceMappingURL=91778.0de783458d0ed5127629.index.js.map