(self.webpackChunkrichie_education=self.webpackChunkrichie_education||[]).push([[2668],{2668:function(){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({data:{nu:["latn"],year:{0:"今年",1:"明年",future:{other:"{0} 年後"},past:{other:"{0} 年前"},"-1":"去年"},"year-short":{0:"今年",1:"明年",future:{other:"{0} 年後"},past:{other:"{0} 年前"},"-1":"去年"},"year-narrow":{0:"今年",1:"明年",future:{other:"{0} 年後"},past:{other:"{0} 年前"},"-1":"去年"},quarter:{0:"這一季",1:"下一季",future:{other:"{0} 季後"},past:{other:"{0} 季前"},"-1":"上一季"},"quarter-short":{0:"這一季",1:"下一季",future:{other:"{0} 季後"},past:{other:"{0} 季前"},"-1":"上一季"},"quarter-narrow":{0:"這一季",1:"下一季",future:{other:"{0} 季後"},past:{other:"{0} 季前"},"-1":"上一季"},month:{0:"本月",1:"下個月",future:{other:"{0} 個月後"},past:{other:"{0} 個月前"},"-1":"上個月"},"month-short":{0:"本月",1:"下個月",future:{other:"{0} 個月後"},past:{other:"{0} 個月前"},"-1":"上個月"},"month-narrow":{0:"本月",1:"下個月",future:{other:"{0} 個月後"},past:{other:"{0} 個月前"},"-1":"上個月"},week:{0:"本週",1:"下週",future:{other:"{0} 週後"},past:{other:"{0} 週前"},"-1":"上週"},"week-short":{0:"本週",1:"下週",future:{other:"{0} 週後"},past:{other:"{0} 週前"},"-1":"上週"},"week-narrow":{0:"本週",1:"下週",future:{other:"{0} 週後"},past:{other:"{0} 週前"},"-1":"上週"},day:{0:"今天",1:"明天",2:"後天",future:{other:"{0} 天後"},past:{other:"{0} 天前"},"-2":"前天","-1":"昨天"},"day-short":{0:"今天",1:"明天",2:"後天",future:{other:"{0} 天後"},past:{other:"{0} 天前"},"-2":"前天","-1":"昨天"},"day-narrow":{0:"今天",1:"明天",2:"後天",future:{other:"{0} 天後"},past:{other:"{0} 天前"},"-2":"前天","-1":"昨天"},hour:{0:"這一小時",future:{other:"{0} 小時後"},past:{other:"{0} 小時前"}},"hour-short":{0:"這一小時",future:{other:"{0} 小時後"},past:{other:"{0} 小時前"}},"hour-narrow":{0:"這一小時",future:{other:"{0} 小時後"},past:{other:"{0} 小時前"}},minute:{0:"這一分鐘",future:{other:"{0} 分鐘後"},past:{other:"{0} 分鐘前"}},"minute-short":{0:"這一分鐘",future:{other:"{0} 分鐘後"},past:{other:"{0} 分鐘前"}},"minute-narrow":{0:"這一分鐘",future:{other:"{0} 分鐘後"},past:{other:"{0} 分鐘前"}},second:{0:"現在",future:{other:"{0} 秒後"},past:{other:"{0} 秒前"}},"second-short":{0:"現在",future:{other:"{0} 秒後"},past:{other:"{0} 秒前"}},"second-narrow":{0:"現在",future:{other:"{0} 秒後"},past:{other:"{0} 秒前"}}},locale:"zh-Hant"})}}]);
//# sourceMappingURL=2668.0de783458d0ed5127629.index.js.map